Learn R Programming

schumaker (version 1.2.2)

SchumakerIndInterval: SchumakerIndInterval

Description

This creates quadratic coefficients for one interval of a domain. This is an internal function that is called from the Schumaker function.

Usage

SchumakerIndInterval(z, s, Smallt)

Value

The location of the knot and quadratic coefficients for an interval.

Arguments

z

This is the y value at edges of an interval.

s

This is the slope at edges of an interval.

Smallt

This is x values at the edge of an interval.